@@ -1,11 +1,11 @@
 #!/usr/bin/python3
-# vim:set fileencoding=utf-8 filetype=python tabstop=4 shiftwidth=4 expandtab:
 from __future__ import print_function
 
 import json
 from itertools import groupby
 from operator import itemgetter
 
+
 try:
     from typing import Dict, Iterable, List, Tuple  # noqa: F401
 except ImportError:
@@ -33,22 +33,22 @@ def gen_releases(releases=[], major=MAJOR, minor=MINOR, patches=range(0, PATCH +
     True
     """
     releases = list(releases) or [(major, minor, patch) for patch in patches]
-    data = dict(
-        releases=[
-            dict(
-                major=major,
-                minors=[
-                    dict(
-                        minor=minor,
-                        patchlevels=[
-                            dict(
-                                patchlevel=patchlevel,
-                                status="maintained",
-                            ) for major, minor, patchlevel in patchelevels  # noqa: F812
-                        ]
-                    ) for minor, patchelevels in groupby(minors, key=itemgetter(1))  # noqa: F812
-                ]
-            ) for major, minors in groupby(releases, key=itemgetter(0))  # noqa: F812
-        ]
-    )
+    data = {
+        "releases": [
+            {
+                "major": major,
+                "minors": [
+                    {
+                        "minor": minor,
+                        "patchlevels": [
+                            {
+                                "patchlevel": patchlevel,
+                                "status": "maintained",
+                            } for major, minor, patchlevel in patchelevels  # noqa: F812
+                        ],
+                    } for minor, patchelevels in groupby(minors, key=itemgetter(1))  # noqa: F812
+                ],
+            } for major, minors in groupby(releases, key=itemgetter(0))  # noqa: F812
+        ],
+    }
     return json.dumps(data).encode('UTF-8')
